@@ -5,7 +5,7 @@ from time import sleep
 import subprocess
 import sys
 
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 
 MAJOR = "major"
 MINOR = "minor"
@@ -52,7 +52,7 @@ def get_last_tag():
 
 def get_all_tags():
     """Get all annotated (closest) tags by lexicographic order."""
-    tags = run("git tag --sort=-refname").split("\n")
+    tags = run("git tag --sort -v:refname").split("\n")
 
     # Parse semver tag: v0.0.0-xxxx (optional suffix).
     out = []
